@@ -10,16 +10,16 @@ from peek_plugin_graphdb._private.storage.GraphDbModelSet import GraphDbModelSet
 
 @addTupleType
 class GraphDbSegment(Tuple, DeclarativeBase):
-    __tupleType__ = graphDbTuplePrefix + 'GraphDbSegmentTable'
-    __tablename__ = 'GraphDbSegment'
+    __tupleType__ = graphDbTuplePrefix + "GraphDbSegmentTable"
+    __tablename__ = "GraphDbSegment"
 
     #:  The unique ID of this segment (database generated)
     id = Column(BigInteger, primary_key=True, autoincrement=True)
 
     #:  The model set for this segment
-    modelSetId = Column(Integer,
-                        ForeignKey('GraphDbModelSet.id', ondelete='CASCADE'),
-                        nullable=False)
+    modelSetId = Column(
+        Integer, ForeignKey("GraphDbModelSet.id", ondelete="CASCADE"), nullable=False
+    )
     modelSet = relationship(GraphDbModelSet)
 
     importGroupHash = Column(String, nullable=False)
