@@ -1,11 +1,12 @@
-import { Injectable } from "@angular/core"
-import { NgLifeCycleEvents, TupleSelector } from "@synerty/vortexjs"
-import { PrivateTracerService } from "./_private/tracer-service"
-import { GraphDbTraceResultTuple } from "./GraphDbTraceResultTuple"
-import { GraphDbLinkedModel } from "./GraphDbLinkedModel"
-import { GraphDbTupleService } from "./_private"
-import { GraphDbTraceConfigTuple } from "./_private/tuples/GraphDbTraceConfigTuple"
-import { Observable } from "rxjs"
+import { Injectable } from "@angular/core";
+import { NgLifeCycleEvents, TupleSelector } from "@synerty/vortexjs";
+import { PrivateTracerService } from "./_private/tracer-service";
+import { GraphDbTraceResultTuple } from "./GraphDbTraceResultTuple";
+import { GraphDbLinkedModel } from "./GraphDbLinkedModel";
+import { GraphDbTupleService } from "./_private";
+import { GraphDbTraceConfigTuple } from "./_private/tuples/GraphDbTraceConfigTuple";
+import { map } from "rxjs/operators";
+import { Observable } from "rxjs";
 
 export interface TraceConfigListItemI {
     name: string;
@@ -25,14 +26,13 @@ export interface TraceConfigListItemI {
  */
 @Injectable()
 export class GraphDbService extends NgLifeCycleEvents {
-    
     constructor(
         private tupleService: GraphDbTupleService,
         private tracerService: PrivateTracerService
     ) {
-        super()
+        super();
     }
-    
+
     /** Does Key Exist
      *
      * Does the key exist in the GraphDB Model
@@ -42,9 +42,9 @@ export class GraphDbService extends NgLifeCycleEvents {
         modelSetKey: string,
         vertexOrEdgeKey: string
     ): Promise<boolean> {
-        return this.tracerService.doesKeyExist(modelSetKey, vertexOrEdgeKey)
+        return this.tracerService.doesKeyExist(modelSetKey, vertexOrEdgeKey);
     }
-    
+
     /** Get Trace Result
      *
      * Trace the graph with a pre-defined trace rule, and return a flat model
@@ -56,11 +56,14 @@ export class GraphDbService extends NgLifeCycleEvents {
         startVertexKey: string,
         maxVertexes: number | null = null
     ): Promise<GraphDbTraceResultTuple> {
-        
-        return this.tracerService
-            .runTrace(modelSetKey, traceConfigKey, startVertexKey, maxVertexes)
+        return this.tracerService.runTrace(
+            modelSetKey,
+            traceConfigKey,
+            startVertexKey,
+            maxVertexes
+        );
     }
-    
+
     /** Get Trace Model
      *
      * Trace the graph with a pre-defined trace rule, and return a linked model
@@ -72,48 +75,43 @@ export class GraphDbService extends NgLifeCycleEvents {
         startVertexKey: string,
         maxVertexes: number | null = null
     ): Promise<GraphDbLinkedModel> {
-        
         return this.tracerService
             .runTrace(modelSetKey, traceConfigKey, startVertexKey, maxVertexes)
             .then((result: GraphDbTraceResultTuple) => {
-                return GraphDbLinkedModel.createFromTraceResult(result)
-            })
-        
+                return GraphDbLinkedModel.createFromTraceResult(result);
+            });
     }
-    
+
     /** Trace Config List Items Observable
      *
      * Trace the graph with a pre-defined trace rule, and return a linked model
      *
      */
-    traceConfigListItemsObservable(modelSetKey: string): Observable<TraceConfigListItemI[]> {
-        
+    traceConfigListItemsObservable(
+        modelSetKey: string
+    ): Observable<TraceConfigListItemI[]> {
         const ts = new TupleSelector(GraphDbTraceConfigTuple.tupleName, {
-            modelSetKey: modelSetKey
-        })
-        
-        return this.tupleService
-            .offlineObserver
+            modelSetKey: modelSetKey,
+        });
+
+        return this.tupleService.offlineObserver
             .subscribeToTupleSelector(ts)
-            .map((tuples: GraphDbTraceConfigTuple[]) => {
-                const out = []
-                tuples.sort((
-                    a,
-                    b
-                    ) =>
+            .pipe(
+                map((tuples: GraphDbTraceConfigTuple[]) => {
+                    const out = [];
+                    tuples.sort((a, b) =>
                         a.title == b.title ? 0 : a.title < b.title ? -1 : 1
-                )
-                for (let tuple of tuples) {
-                    if (!tuple.isEnabled) continue
-                    out.push({
-                        name: tuple.name,
-                        title: tuple.title,
-                        key: tuple.key
-                    })
-                }
-                return out
-            })
-        
+                    );
+                    for (let tuple of tuples) {
+                        if (!tuple.isEnabled) continue;
+                        out.push({
+                            name: tuple.name,
+                            title: tuple.title,
+                            key: tuple.key,
+                        });
+                    }
+                    return out;
+                })
+            );
     }
-    
 }
